==> ocstore25_4_23.zip: OcStore/Prgm/data/map/CS_santa_house.lua <==
function E0090()
    SetColonAction()
    MNA()FAI(0)
end
function E0091()
    SetColonAction()
    MNA()FAI(1)
end
function E0092()
    SetColonAction()
    MNA()FAI(2)
end
function E0093()
    SetColonAction()
    MNA()FAI(3)
end
function E0094()
    SetColonAction()
    MNA()FAI(4)
end

--设置科恩动作
function SetColonAction()
    if(FLJ("KingBack")) then
        MNP("Colon4",18,19,1)
        MNP("Colon3",19,19,1)
        MNP("Colon2",21,19,1)
        MNP("Colon1",22,19,1)
        ANP("Colon4","sit",1)
        ANP("Colon3","sit",0)
        ANP("Colon2","sleep",1)
        ANP("Colon1","sleep",1)
        DNP("Fireplace1")
        CMU("CS_Kodou")
    else
        ANP("Colon1","sit")--坐着的
        ANP("Colon2","sit")--坐着的
        ANP("Colon3","sit")--坐着的
        ANP("Colon4","sit")--坐着的
        CMU("CS_Anzen")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",14,15)
end

--科恩1
function Colon1()
    KEY()MS3("因为有妖怪出现了，")NOD()
    CAT("\n恰可姐姐为了保护我们")
    CAT("\n就把我们都转移回来了")NOD()
    if(FLJ("Colon1GiveExp")) then
        SNP("CS_exp_placer",20,12,0,"mainLayer","ExpPlacer1")
        ANP("ExpPlacer1",9)
        FLS("Colon1GiveExp")
    end
end

function Colon2()
    KEY()MS3("我好想念卡莉啊")NOD()
    CAT("\n希望她早点回来。")NOD()
    if(FLJ("Colon2GiveExp")) then
        SNP("CS_exp_placer",21,12,0,"mainLayer","ExpPlacer2")
        ANP("ExpPlacer2",9)
        FLS("Colon2GiveExp")
    end
end

function Colon3()
    KEY()MS3("那是真正的枪嘛？")NOD()
    CAT("\n哥哥们一起去打妖怪真是太酷了！")NOD()
    if(FLJ("Colon3GiveExp")) then
        SNP("CS_exp_placer",22,12,0,"mainLayer","ExpPlacer3")
        ANP("ExpPlacer3",9)
        FLS("Colon3GiveExp")
    end
end

function Colon4()
    KEY()MS3("希望数姐姐和多隆子")
    CAT("\n都要平安无事啊。")NOD()
    if(FLJ("Colon4GiveExp")) then
        SNP("CS_exp_placer",23,12,0,"mainLayer","ExpPlacer4")
        ANP("ExpPlacer4",9)
        FLS("Colon4GiveExp")
    end
end

function Chako1()
    KEY()MS3("这里有地下室供孩子们安全的隐藏，")NOD()
    CAT("\n你们放心的去吧。")NOD()CLR()
    if(ITJ("TorokoNecklace")) then
        GIT("TorokoNecklace")
        CAT("是多隆子的项链啊，")NOD()
        CAT("\n也许用项链可以找到她们的地点。")NOD()
    end
    if(FLJ("ChakoGiveExp")) then
        SNP("CS_exp_placer",25,12,0,"mainLayer","ExpPlacer5")
        ANP("ExpPlacer5",29)
        FLS("ChakoGiveExp")
    end
end

function HideInBasement()
    KEY()
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    ANP("Colon1","normal",0)
    ANP("Colon2","normal",0)
    ANP("Colon3","normal",0)
    ANP("Colon4","normal",0)
    DNP("Fireplace1")
    FAI(0)
    MS3("怪物来了！")NOD()
    CAT("\n大家快躲进地下室。")NOD()CLO()
    ANP("Colon4","walk",1)
    WAI(16)
    ANP("Colon4","back",1)
    ANP("Colon3","walk",1)
    WAI(16)
    ANP("Colon2","walk",1)
    MNP("Colon4",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon4","normal",0)
    WAI(15)
    ANP("Colon1","walk",1)
    ANP("Colon3","back",1)
    ANP("Colon4","walk",0)
    WAI(16)
    MNP("Colon3",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon3","normal",0)
    WAI(15)
    ANP("Colon2","back",1)
    ANP("Colon3","walk",0)
    WAI(16)
    MNP("Colon2",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon2","normal",0)
    WAI(14)
    ANP("Colon1","back",1)
    ANP("Colon2","walk",0)
    WAI(16)
    MNP("Colon1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon1","normal",0)
    WAI(16)
    ANP("Chako1","walk",1)
    ANP("Colon1","walk",0)
    WAI(16)
    ANP("Colon4","normal",1)
    WAI(16)
    ANP("Colon3","normal",1)
    WAI(16)
    ANP("Colon2","normal",1)
    WAI(16)
    ANP("Colon1","normal",1)
    WAI(27)
    ANP("Chako1","back",1)
    WAI(16)
    MNP("Chako1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    MS3("大家不要发出声音，")NOD()
    CAT("\n安静的在这里躲着就行了，")NOD()
    CAT("\n怪物是绝对找不到我们的。")NOD()CLR()
    CAT("\n知道了。")NOD()CLO()
    WAI(32)
    PMU(1)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(32)
    SNP("CS_soapwalker_animate",18,14,1,"mainLayer","SoapWalker1")
    ANP("SoapWalker1","look_down",1)
    WAI(32)
    FAC("soapwalker_normal")MS3("\n我的小可爱你们在哪呢？")NOD()CLO()
    ANP("SoapWalker1","walk",1)
    WAI(96)
    ANP("SoapWalker1","walk",0)
    WAI(96)
    WAI(8)
    ANP("SoapWalker1","normal",0)
    ANP("SoapWalker1","look_normal",0)
    WAI(16)
    ANP("SoapWalker1","jump",0)
    WAI(64)
    ANP("SoapWalker1","normal",1)
    WAI(16)
    ANP("SoapWalker1","big_jump",1)
    WAI(64)
    MS3("奇怪了，今天大家怎么都不在呐，")NOD()
    CAT("\n去其他地方看看好了。")CLO()
    WAI(32)
    ANP("SoapWalker1","walk",1)
    WAI(8)
    ANP("SoapWalker1","normal",1)
    WAI(32)
    DNP("SoapWalker1")
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    RMU()
    FAO(2)TRA("CS_king_house","PuuSearch",14,15)
end

function ChakoObserve()
    KEY()
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    DNP("Fireplace1")
    FAI(0)
    QUA(30)
    SOU("CS_026_quake")
    WAI(64)
    MS3("怪物好像离开了呢，")NOD()
    CAT("\n不过听到了不可思议的事情。")NOD()CLR()
    ANP("Chako1","normal",1)
    CAT("这样的话多隆子她们现在")
    CAT("\n应该还是安全的。")NOD()CLR()
    CAT("三只的话，")NOD()
    CAT("\n那另外一只估计就是间八了。")NOD()CLO()
    ANP("Chako1","walk",1)
    WAI(96)
    ANP("Chako1","normal",1)
    WAI(16)
    ANP("Chako1","back",1)
    WAI(16)
    MS3("孩子们，数姐姐她们暂时没事哦，")NOD()
    CAT("\n只是暂时被关到了一个地方。")NOD()CLR()
    CAT("不过在怪物们被击败之前，")NOD()
    CAT("\n我们需要在这里待上几天。")NOD()CLR()
    CAT("\n明白了~")NOD()CLO()
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    MS3("对了，我去村长家拿下这几天的食物，")NOD()
    CAT("\n在我回来前你们绝对不要出来哦。")NOD()CLR()
    CAT("\n好的恰可姐姐。")NOD()CLO()
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(96)
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","back",0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    DNP("Chako1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(16)
    FAO(2)TRA("CS_village","ChakoGoKingHouseGetFood",0,0)
end

function KingBack()
    KEY()
    AMC("normal",1)
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    ANP("Colon4","sit",1)
    ANP("Colon3","sit",0)
    ANP("Colon2","sleep",1)
    ANP("Colon1","sleep",1)
    HMC(0)
    FAI(2)
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(32)
    FAC("king_normal")MS3("桑塔！恰可！？")NOD()
    CAT("\n你们在吗？")NOD()CLO()
    WAI(32)
    AMC("back")
    WAI(32)
    HMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    SNP("CS_exclamation",18,18,0,"mainLayer","null")--感叹号
    WAI(32)
    ANP("Colon4","normal")
    WAI(32)
    ANP("Colon3","normal")
    WAI(32)
    MS3("好像是金村长的声音！")NOD()
    CAT("\n金回来了！")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_bar2","KingBack",28,14)
end

function KingAndColon()
    KEY()
    AMC("normal",0)
    CMU("CS_Kodou")
    FAI(2)
    WAI(32)
    FAC("king_normal")MS3("\n原来是这样。")NOD()CLR()
    CAT("我知道了，")NOD()
    CAT("\n我一定会把大家都救回来的！")NOD()CLR()
    CAT("你们就继续躲在这间屋子里吧，")NOD()
    CAT("\n我去去就回。")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_king_house","KingReadyToGo",16,15)
end

==> ocstore25_6_20.zip: OcStore/Prgm/data/map/CS_santa_house.lua <==
function E0090()
    SetColonAction()
    MNA()FAI(0)
end
function E0091()
    SetColonAction()
    MNA()FAI(1)
end
function E0092()
    SetColonAction()
    MNA()FAI(2)
end
function E0093()
    SetColonAction()
    MNA()FAI(3)
end
function E0094()
    SetColonAction()
    MNA()FAI(4)
end

--设置科恩动作
function SetColonAction()
    if(FLJ("KingBack")) then
        MNP("Colon4",18,19,1)
        MNP("Colon3",19,19,1)
        MNP("Colon2",21,19,1)
        MNP("Colon1",22,19,1)
        ANP("Colon4","sit",1)
        ANP("Colon3","sit",0)
        ANP("Colon2","sleep",1)
        ANP("Colon1","sleep",1)
        DNP("Fireplace1")
        CMU("CS_Kodou")
    else
        ANP("Colon1","sit")--坐着的
        ANP("Colon2","sit")--坐着的
        ANP("Colon3","sit")--坐着的
        ANP("Colon4","sit")--坐着的
        CMU("CS_Anzen")
    end
end

--去外面
function Door_GoVillage()
    PRI()MM0()SOU("CS_011_door")ANP("Door_GoVillage",0,1)FAO(2)TRA("CS_village","E0090",14,15)
end

--科恩1
function Colon1()
    KEY()MS3("因为有妖怪出现了，")NOD()
    CAT("\n恰可姐姐为了保护我们")
    CAT("\n就把我们都转移回来了")NOD()
    if(FLJ("Colon1GiveExp")) then
        SNP("CS_exp_placer",20,12,0,"mainLayer","ExpPlacer1")
        ANP("ExpPlacer1",9)
        FLS("Colon1GiveExp")
    end
end

function Colon2()
    KEY()MS3("我好想念卡莉啊")NOD()
    CAT("\n希望她早点回来。")NOD()
    if(FLJ("Colon2GiveExp")) then
        SNP("CS_exp_placer",21,12,0,"mainLayer","ExpPlacer2")
        ANP("ExpPlacer2",9)
        FLS("Colon2GiveExp")
    end
end

function Colon3()
    KEY()MS3("那是真正的枪嘛？")NOD()
    CAT("\n哥哥们一起去打妖怪真是太酷了！")NOD()
    if(FLJ("Colon3GiveExp")) then
        SNP("CS_exp_placer",22,12,0,"mainLayer","ExpPlacer3")
        ANP("ExpPlacer3",9)
        FLS("Colon3GiveExp")
    end
end

function Colon4()
    KEY()MS3("希望数姐姐和多隆子")
    CAT("\n都要平安无事啊。")NOD()
    if(FLJ("Colon4GiveExp")) then
        SNP("CS_exp_placer",23,12,0,"mainLayer","ExpPlacer4")
        ANP("ExpPlacer4",9)
        FLS("Colon4GiveExp")
    end
end

function Chako1()
    KEY()FAC("chako_happy")MS3("这里有地下室供孩子们安全的隐藏，")NOD()
    CAT("\n你们放心的去吧。")NOD()CLR()
    if(ITJ("TorokoNecklace")) then
        GIT("TorokoNecklace")
        FAC("chako_normal")CAT("是多隆子的项链啊，")NOD()
        CAT("\n也许用项链可以找到她们的地点。")NOD()
    end
    if(FLJ("ChakoGiveExp")) then
        SNP("CS_exp_placer",25,12,0,"mainLayer","ExpPlacer5")
        ANP("ExpPlacer5",29)
        FLS("ChakoGiveExp")
    end
end

function HideInBasement()
    KEY()
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    ANP("Colon1","normal",0)
    ANP("Colon2","normal",0)
    ANP("Colon3","normal",0)
    ANP("Colon4","normal",0)
    DNP("Fireplace1")
    FAI(0)
    FAC("chako_normal")MS3("怪物来了！")NOD()
    CAT("\n大家快躲进地下室。")NOD()CLO()
    ANP("Colon4","walk",1)
    WAI(16)
    ANP("Colon4","back",1)
    ANP("Colon3","walk",1)
    WAI(16)
    ANP("Colon2","walk",1)
    MNP("Colon4",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon4","normal",0)
    WAI(15)
    ANP("Colon1","walk",1)
    ANP("Colon3","back",1)
    ANP("Colon4","walk",0)
    WAI(16)
    MNP("Colon3",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon3","normal",0)
    WAI(15)
    ANP("Colon2","back",1)
    ANP("Colon3","walk",0)
    WAI(16)
    MNP("Colon2",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon2","normal",0)
    WAI(14)
    ANP("Colon1","back",1)
    ANP("Colon2","walk",0)
    WAI(16)
    MNP("Colon1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Colon1","normal",0)
    WAI(16)
    ANP("Chako1","walk",1)
    ANP("Colon1","walk",0)
    WAI(16)
    ANP("Colon4","normal",1)
    WAI(16)
    ANP("Colon3","normal",1)
    WAI(16)
    ANP("Colon2","normal",1)
    WAI(16)
    ANP("Colon1","normal",1)
    WAI(27)
    ANP("Chako1","back",1)
    WAI(16)
    MNP("Chako1",24,16,0)
    SNP("CS_pe_smoke",24,14,0,"mainLayer","")
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_normal")MS3("大家不要发出声音，")NOD()
    CAT("\n安静的在这里躲着就行了，")NOD()
    CAT("\n怪物是绝对找不到我们的。")NOD()CLR()
    FAC()CAT("\n知道了。")NOD()CLO()
    WAI(32)
    PMU(1)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(32)
    SNP("CS_soapwalker_animate",18,14,1,"mainLayer","SoapWalker1")
    ANP("SoapWalker1","look_down",1)
    WAI(32)
    FAC("soapwalker_normal")MS3("\n我的小可爱你们在哪呢？")NOD()CLO()
    ANP("SoapWalker1","walk",1)
    WAI(96)
    ANP("SoapWalker1","walk",0)
    WAI(96)
    WAI(8)
    ANP("SoapWalker1","normal",0)
    ANP("SoapWalker1","look_normal",0)
    WAI(16)
    ANP("SoapWalker1","jump",0)
    WAI(64)
    ANP("SoapWalker1","normal",1)
    WAI(16)
    ANP("SoapWalker1","big_jump",1)
    WAI(64)
    MS3("奇怪了，今天大家怎么都不在呐，")NOD()
    CAT("\n去其他地方看看好了。")CLO()
    WAI(32)
    ANP("SoapWalker1","walk",1)
    WAI(8)
    ANP("SoapWalker1","normal",1)
    WAI(32)
    DNP("SoapWalker1")
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    RMU()
    FAO(2)TRA("CS_king_house","PuuSearch",14,15)
end

function ChakoObserve()
    KEY()
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    MNP("Chako1",18,14,1)
    ANP("Chako1","back",1)
    DNP("Fireplace1")
    FAI(0)
    QUA(30)
    SOU("CS_026_quake")
    WAI(64)
    FAC("chako_normal")MS3("怪物好像离开了呢，")NOD()
    CAT("\n不过听到了不可思议的事情。")NOD()CLR()
    ANP("Chako1","normal",1)
    CAT("这样的话多隆子她们现在")
    CAT("\n应该还是安全的。")NOD()CLR()
    CAT("三只的话，")NOD()
    CAT("\n那另外一只估计就是间八了。")NOD()CLO()
    ANP("Chako1","walk",1)
    WAI(96)
    ANP("Chako1","normal",1)
    WAI(16)
    ANP("Chako1","back",1)
    WAI(16)
    FAC("chako_happy")MS3("孩子们，数姐姐她们暂时没事哦，")NOD()
    CAT("\n只是暂时被关到了一个地方。")NOD()CLR()
    CAT("不过在怪物们被击败之前，")NOD()
    CAT("\n我们需要在这里待上几天。")NOD()CLR()
    FAC()CAT("\n明白了~")NOD()CLO()
    WAI(32)
    ANP("Chako1","normal",0)
    WAI(32)
    FAC("chako_happy")MS3("对了，我去村长家拿下这几天的食物，")NOD()
    CAT("\n在我回来前你们绝对不要出来哦。")NOD()CLR()
    FAC()CAT("\n好的恰可姐姐。")NOD()CLO()
    WAI(16)
    ANP("Chako1","walk",0)
    WAI(96)
    ANP("Chako1","normal",0)
    WAI(16)
    ANP("Chako1","back",0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    DNP("Chako1")
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(16)
    FAO(2)TRA("CS_village","ChakoGoKingHouseGetFood",0,0)
end

function KingBack()
    KEY()
    AMC("normal",1)
    MNP("Colon4",18,19,1)
    MNP("Colon3",19,19,1)
    MNP("Colon2",21,19,1)
    MNP("Colon1",22,19,1)
    ANP("Colon4","sit",1)
    ANP("Colon3","sit",0)
    ANP("Colon2","sleep",1)
    ANP("Colon1","sleep",1)
    HMC(0)
    FAI(2)
    WAI(32)
    SOU("CS_011_door")ANP("Door_GoVillage",0,1)
    WAI(16)
    SMC(0)
    WAI(32)
    FAC("king_normal")MS3("桑塔！恰可！？")NOD()
    CAT("\n你们在吗？")NOD()CLO()
    WAI(32)
    AMC("back")
    WAI(32)
    HMC(0)
    WAI(16)
    SOU("CS_011_door")ANP("Door_GoVillage",0,0)
    WAI(32)
    SNP("CS_exclamation",18,18,0,"mainLayer","null")--感叹号
    WAI(32)
    ANP("Colon4","normal")
    WAI(32)
    ANP("Colon3","normal")
    WAI(32)
    MS3("好像是金村长的声音！")NOD()
    CAT("\n金回来了！")NOD()CLO()
    WAI(16)
    FAO(0)
    TRA("CS_bar2","KingBack",28,14)
end

function KingAndColon()
    KEY()
    AMC("normal",0)
    CMU("CS_Kodou")
    FAI(2)
    WAI(32)
    FAC("king_normal")MS3("\n原来是这样。")NOD()CLR()
    CAT("我知道了，")NOD()
    CAT("\n我一定会把大家都救回来的！")NOD()CLR()
    CAT("你们就继续躲在这间屋子里吧，")NOD()
    CAT("\n我去去就回。")NOD()CLO()
    WAI(32)
    FAO(0)
    TRA("CS_king_house","KingReadyToGo",16,15)
end
